@@ -51,7 +51,4 @@ from .asm_v1 import QickProgram
 # only import the hardware drivers if running on a Zynq
 # also import if we're in the ReadTheDocs Sphinx build (the imports won't really work but they will be mocked)
 if platform.machine() in ['aarch64', 'armv7l'] or os.getenv('READTHEDOCS', default='False')=='True':
-    try:
-        from .qick import QickSoc
-    except Exception as e:
-        print("Could not import QickSoc:", e)
+    from .qick import QickSoc
