@@ -21,6 +21,8 @@ from .asm_v2 import QickProgramV2
 from .drivers.generator import *
 from .drivers.readout import *
 from .drivers.tproc import *
+from .drivers.peripherals import *
+from .drivers.xcom import *
 
 logger = logging.getLogger(__name__)
 
